@@ -2,7 +2,7 @@
 Author: Vincent Young
 Date: 2022-07-24 03:56:22
 LastEditors: Vincent Young
-LastEditTime: 2022-07-24 18:50:26
+LastEditTime: 2022-10-16 08:54:19
 FilePath: /GenchAPI/GenchAPI/GenchAPI.py
 Telegram: https://t.me/missuo
 
@@ -13,7 +13,7 @@ import requests
 from bs4 import BeautifulSoup
 import json
 
-def sign(userid, password):
+def sign(userid, password, ischool=None):
     session = requests.session()
     url =  'https://cas.gench.edu.cn/cas/login'
     headers = {
@@ -161,7 +161,9 @@ def sign(userid, password):
             'Content-Type': 'application/x-www-form-urlencoded;charset=utf-8'
         }
         
-        ischool = "0"
+        ischool = "1"
+        if(ischool == 0):
+            ischool = "0"
         add_data = {
             "type":"学生",
             "uuid":uuid,
